@@ -23,9 +23,11 @@
 #include "dbconfigmysqlembedded.h"
 #include "dbconfigpostgresql.h"
 #include "dbconfigsqlite.h"
+#include "dbconfigvirtuoso.h"
 
 #include <akdebug.h>
 #include <libs/xdgbasedirs_p.h>
+#include <config-akonadi.h>
 
 #include <QtCore/QDir>
 
@@ -64,10 +66,13 @@ DbConfig* DbConfig::configuredDatabase()
     QSettings settings( serverConfigFile, QSettings::IniFormat );
 
     // determine driver to use
-    const QString defaultDriver = QLatin1String( "QMYSQL" );
-    QString driverName = settings.value( QLatin1String( "General/Driver" ), defaultDriver ).toString();
-    if ( driverName.isEmpty() )
-      driverName = defaultDriver;
+    QString driverName = settings.value( QLatin1String( "General/Driver" ) ).toString();
+    if ( driverName.isEmpty() ) {
+      driverName = QLatin1String( AKONADI_DATABASE_BACKEND );
+      // when using the default, write it explicitly, in case the default changes later
+      settings.setValue( QLatin1String("General/Driver"), driverName );
+      settings.sync();
+    }
 
     if ( driverName == QLatin1String( "QMYSQL" ) )
       s_DbConfigInstance = new DbConfigMysql;
@@ -79,6 +84,8 @@ DbConfig* DbConfig::configuredDatabase()
       s_DbConfigInstance = new DbConfigSqlite( DbConfigSqlite::Custom );
     else if ( driverName == QLatin1String( "QPSQL" ) )
       s_DbConfigInstance = new DbConfigPostgresql;
+    else if ( driverName == QLatin1String( "QODBC" ) )
+      s_DbConfigInstance = new DbConfigVirtuoso;
     else {
       akError() << "Unknown database driver: " << driverName;
       akError() << "Available drivers are: " << QSqlDatabase::drivers();
@@ -99,6 +106,11 @@ void DbConfig::stopInternalServer()
   // do nothing
 }
 
+void DbConfig::setup()
+{
+  // do nothing
+}
+
 qint64 DbConfig::sizeThreshold() const
 {
   return mSizeThreshold;
